====================================
:mod:`trakt.core.context_collection`
====================================
.. automodule:: trakt.core.context_collection
  :members:
  :undoc-members:
  :show-inheritance:
